@@ -9,7 +9,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.1018';
+$VERSION = '2.1019';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -35,6 +35,10 @@ sub driver{
     $drh;
 }
 
+sub CLONE {
+  undef $drh;
+}
+
 sub _OdbcParse($$$) {
     my($class, $dsn, $hash, $args) = @_;
     my($var, $val);
